==> haskell-edisonapi-1.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-KjkUBwUQ9QtGMmEyFW5iNe
key: EdisonAPI-1.3.1-KjkUBwUQ9QtGMmEyFW5iNe
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
exposed-modules:
    Data.Edison Data.Edison.Prelude Data.Edison.Sym Data.Edison.Assoc
    Data.Edison.Coll Data.Edison.Coll.Utils Data.Edison.Seq
    Data.Edison.Seq.ListSeq
abi: 80de1afca6f1e167651606297980bbec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/EdisonAPI-1.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-KjkUBwUQ9QtGMmEyFW5iNe
depends:
    base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisonapi-1.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-edisonapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonAPI
version: 1.3.1
id: EdisonAPI-1.3.1-Lc50zqrgqRXwTkScExXSx
key: EdisonAPI-1.3.1-Lc50zqrgqRXwTkScExXSx
license: MIT
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (API)
description:
    Edison is a library of purely functional data structures written by
    Chris Okasaki.  It is named after Thomas Alva Edison and for the
    mnemonic value EDiSon (Efficient Data Structures).
    Edison provides several families of abstractions, each with
    multiple implementations.  The main abstractions provided by Edison are:
    Sequences such as stacks, queues, and dequeues;
    Collections such as sets, bags and heaps; and
    Associative Collections such as finite maps and priority queues
    where the priority and element are distinct.
category: Data Structures
author: Chris Okasaki
exposed: True
exposed-modules:
    Data.Edison Data.Edison.Prelude Data.Edison.Sym Data.Edison.Assoc
    Data.Edison.Coll Data.Edison.Coll.Utils Data.Edison.Seq
    Data.Edison.Seq.ListSeq
abi: eb142f8ce9f3f94d0c8ed88f4353f22c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/EdisonAPI-1.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/EdisonAPI-1.3.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/EdisonAPI-1.3.1
hs-libraries: HSEdisonAPI-1.3.1-Lc50zqrgqRXwTkScExXSx
depends:
    base-4.9.1.0 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
haddock-interfaces: /usr/share/doc/haskell-edisonapi/html/EdisonAPI.haddock
haddock-html: /usr/share/doc/haskell-edisonapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
